==> apache-seatunnel-2.3.5-src.tar.gz: apache-seatunnel-2.3.5-src/seatunnel-connectors-v2/connector-paimon/src/main/java/org/apache/seatunnel/connectors/seatunnel/paimon/utils/RowKindConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.paimon.utils;

import org.apache.seatunnel.api.table.type.RowKind;
import org.apache.seatunnel.common.exception.CommonErrorCode;
import org.apache.seatunnel.connectors.seatunnel.paimon.exception.PaimonConnectorException;

import org.apache.paimon.data.InternalRow;

public class RowKindConverter {

    /**
     * Convert SeaTunnel RowKind {@link RowKind} to Paimon RowKind {@link InternalRow}
     *
     * @param seaTunnelRowInd
     * @return
     */
    public static org.apache.paimon.types.RowKind convertSeaTunnelRowKind2PaimonRowKind(
            RowKind seaTunnelRowInd) {
        switch (seaTunnelRowInd) {
            case DELETE:
                return org.apache.paimon.types.RowKind.DELETE;
            case UPDATE_AFTER:
                return org.apache.paimon.types.RowKind.UPDATE_AFTER;
            case UPDATE_BEFORE:
                return org.apache.paimon.types.RowKind.UPDATE_BEFORE;
            case INSERT:
                return org.apache.paimon.types.RowKind.INSERT;
            default:
                throw new PaimonConnectorException(
                        CommonErrorCode.UNSUPPORTED_DATA_TYPE,
                        "Unsupported rowKind type " + seaTunnelRowInd.shortString());
        }
    }
}

==> apache-seatunnel-2.3.6-src.tar.gz: apache-seatunnel-2.3.6-src/seatunnel-connectors-v2/connector-paimon/src/main/java/org/apache/seatunnel/connectors/seatunnel/paimon/utils/RowKindConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.paimon.utils;

import org.apache.seatunnel.api.table.type.RowKind;

import org.apache.paimon.data.InternalRow;

public class RowKindConverter {

    /**
     * Convert SeaTunnel RowKind {@link RowKind} to Paimon RowKind {@link InternalRow}
     *
     * @param seaTunnelRowKind The kind of change that a row describes in a changelog.
     * @return
     */
    public static org.apache.paimon.types.RowKind convertSeaTunnelRowKind2PaimonRowKind(
            RowKind seaTunnelRowKind) {
        switch (seaTunnelRowKind) {
            case DELETE:
                return org.apache.paimon.types.RowKind.DELETE;
            case UPDATE_AFTER:
                return org.apache.paimon.types.RowKind.UPDATE_AFTER;
            case UPDATE_BEFORE:
                return org.apache.paimon.types.RowKind.UPDATE_BEFORE;
            case INSERT:
                return org.apache.paimon.types.RowKind.INSERT;
            default:
                return null;
        }
    }
}
